@@ -10,4 +10,4 @@ cd $(dirname "$0")/..
 python3 -m virtualenv venv/
 
 # Install dependencies
-venv/bin/pip install --user -e .
+venv/bin/pip install -e .
